@@ -53,23 +53,23 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import cdk8s
-import cdktf
-import cdktf_cdktf_provider_kubernetes
-import constructs
+import cdk8s as _cdk8s_d3d9af27
+import cdktf as _cdktf_9a9027ec
+import cdktf_cdktf_provider_kubernetes.provider as _cdktf_cdktf_provider_kubernetes_provider_b14d7399
+import constructs as _constructs_77d1e7e8
 
 
 class CDK8sProvider(
-    cdktf_cdktf_provider_kubernetes.KubernetesProvider,
+    _cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProvider,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdktf-cdk8s.CDK8sProvider",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        cdk8s_app: cdk8s.App,
+        cdk8s_app: _cdk8s_d3d9af27.App,
         alias: typing.Optional[builtins.str] = None,
         client_certificate: typing.Optional[builtins.str] = None,
         client_key: typing.Optional[builtins.str] = None,
@@ -79,12 +79,12 @@ class CDK8sProvider(
         config_context_cluster: typing.Optional[builtins.str] = None,
         config_path: typing.Optional[builtins.str] = None,
         config_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
-        exec: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec, typing.Dict[str, typing.Any]]] = None,
-        experiments: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments, typing.Dict[str, typing.Any]]] = None,
+        exec: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExec, typing.Dict[builtins.str, typing.Any]]] = None,
+        experiments: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExperiments, typing.Dict[builtins.str, typing.Any]]] = None,
         host: typing.Optional[builtins.str] = None,
         ignore_annotations: typing.Optional[typing.Sequence[builtins.str]] = None,
         ignore_labels: typing.Optional[typing.Sequence[builtins.str]] = None,
-        insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         password: typing.Optional[builtins.str] = None,
         proxy_url: typing.Optional[builtins.str] = None,
         token: typing.Optional[builtins.str] = None,
@@ -115,7 +115,7 @@ class CDK8sProvider(
         :param username: The username to use for HTTP basic authentication when accessing the Kubernetes master endpoint. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#username KubernetesProvider#username}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CDK8sProvider.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c1318c333a56de3bcab994349ad716a730c79b7743c7f471bcd586a5025ca0ab)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = CDK8sProviderConfig(
@@ -146,7 +146,9 @@ class CDK8sProvider(
 
 @jsii.data_type(
     jsii_type="cdktf-cdk8s.CDK8sProviderConfig",
-    jsii_struct_bases=[cdktf_cdktf_provider_kubernetes.KubernetesProviderConfig],
+    jsii_struct_bases=[
+        _cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderConfig
+    ],
     name_mapping={
         "alias": "alias",
         "client_certificate": "clientCertificate",
@@ -170,7 +172,9 @@ class CDK8sProvider(
         "cdk8s_app": "cdk8sApp",
     },
 )
-class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConfig):
+class CDK8sProviderConfig(
+    _cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderConfig,
+):
     def __init__(
         self,
         *,
@@ -183,17 +187,17 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
         config_context_cluster: typing.Optional[builtins.str] = None,
         config_path: typing.Optional[builtins.str] = None,
         config_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
-        exec: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec, typing.Dict[str, typing.Any]]] = None,
-        experiments: typing.Optional[typing.Union[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments, typing.Dict[str, typing.Any]]] = None,
+        exec: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExec, typing.Dict[builtins.str, typing.Any]]] = None,
+        experiments: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExperiments, typing.Dict[builtins.str, typing.Any]]] = None,
         host: typing.Optional[builtins.str] = None,
         ignore_annotations: typing.Optional[typing.Sequence[builtins.str]] = None,
         ignore_labels: typing.Optional[typing.Sequence[builtins.str]] = None,
-        insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         password: typing.Optional[builtins.str] = None,
         proxy_url: typing.Optional[builtins.str] = None,
         token: typing.Optional[builtins.str] = None,
         username: typing.Optional[builtins.str] = None,
-        cdk8s_app: cdk8s.App,
+        cdk8s_app: _cdk8s_d3d9af27.App,
     ) -> None:
         '''
         :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#alias KubernetesProvider#alias}
@@ -218,11 +222,11 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
         :param cdk8s_app: 
         '''
         if isinstance(exec, dict):
-            exec = cdktf_cdktf_provider_kubernetes.KubernetesProviderExec(**exec)
+            exec = _cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExec(**exec)
         if isinstance(experiments, dict):
-            experiments = cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments(**experiments)
+            experiments = _cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExperiments(**experiments)
         if __debug__:
-            type_hints = typing.get_type_hints(CDK8sProviderConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__eca8720f2b770ba7124f7697d37cde3f0db7c9415eb821ddccf066e9fa5cec5c)
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument client_certificate", value=client_certificate, expected_type=type_hints["client_certificate"])
             check_type(argname="argument client_key", value=client_key, expected_type=type_hints["client_key"])
@@ -243,7 +247,7 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
             check_type(argname="argument token", value=token, expected_type=type_hints["token"])
             check_type(argname="argument username", value=username, expected_type=type_hints["username"])
             check_type(argname="argument cdk8s_app", value=cdk8s_app, expected_type=type_hints["cdk8s_app"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "cdk8s_app": cdk8s_app,
         }
         if alias is not None:
@@ -360,24 +364,24 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
     @builtins.property
     def exec(
         self,
-    ) -> typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec]:
+    ) -> typing.Optional[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExec]:
         '''exec block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#exec KubernetesProvider#exec}
         '''
         result = self._values.get("exec")
-        return typing.cast(typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExec], result)
+        return typing.cast(typing.Optional[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExec], result)
 
     @builtins.property
     def experiments(
         self,
-    ) -> typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments]:
+    ) -> typing.Optional[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExperiments]:
         '''experiments block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#experiments KubernetesProvider#experiments}
         '''
         result = self._values.get("experiments")
-        return typing.cast(typing.Optional[cdktf_cdktf_provider_kubernetes.KubernetesProviderExperiments], result)
+        return typing.cast(typing.Optional[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExperiments], result)
 
     @builtins.property
     def host(self) -> typing.Optional[builtins.str]:
@@ -413,13 +417,13 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
     @builtins.property
     def insecure(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Whether server should be accessed without verifying the TLS certificate.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes#insecure KubernetesProvider#insecure}
         '''
         result = self._values.get("insecure")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def password(self) -> typing.Optional[builtins.str]:
@@ -458,10 +462,10 @@ class CDK8sProviderConfig(cdktf_cdktf_provider_kubernetes.KubernetesProviderConf
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def cdk8s_app(self) -> cdk8s.App:
+    def cdk8s_app(self) -> _cdk8s_d3d9af27.App:
         result = self._values.get("cdk8s_app")
         assert result is not None, "Required property 'cdk8s_app' is missing"
-        return typing.cast(cdk8s.App, result)
+        return typing.cast(_cdk8s_d3d9af27.App, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -481,3 +485,57 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c1318c333a56de3bcab994349ad716a730c79b7743c7f471bcd586a5025ca0ab(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    cdk8s_app: _cdk8s_d3d9af27.App,
+    alias: typing.Optional[builtins.str] = None,
+    client_certificate: typing.Optional[builtins.str] = None,
+    client_key: typing.Optional[builtins.str] = None,
+    cluster_ca_certificate: typing.Optional[builtins.str] = None,
+    config_context: typing.Optional[builtins.str] = None,
+    config_context_auth_info: typing.Optional[builtins.str] = None,
+    config_context_cluster: typing.Optional[builtins.str] = None,
+    config_path: typing.Optional[builtins.str] = None,
+    config_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    exec: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExec, typing.Dict[builtins.str, typing.Any]]] = None,
+    experiments: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExperiments, typing.Dict[builtins.str, typing.Any]]] = None,
+    host: typing.Optional[builtins.str] = None,
+    ignore_annotations: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ignore_labels: typing.Optional[typing.Sequence[builtins.str]] = None,
+    insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    password: typing.Optional[builtins.str] = None,
+    proxy_url: typing.Optional[builtins.str] = None,
+    token: typing.Optional[builtins.str] = None,
+    username: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eca8720f2b770ba7124f7697d37cde3f0db7c9415eb821ddccf066e9fa5cec5c(
+    *,
+    alias: typing.Optional[builtins.str] = None,
+    client_certificate: typing.Optional[builtins.str] = None,
+    client_key: typing.Optional[builtins.str] = None,
+    cluster_ca_certificate: typing.Optional[builtins.str] = None,
+    config_context: typing.Optional[builtins.str] = None,
+    config_context_auth_info: typing.Optional[builtins.str] = None,
+    config_context_cluster: typing.Optional[builtins.str] = None,
+    config_path: typing.Optional[builtins.str] = None,
+    config_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    exec: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExec, typing.Dict[builtins.str, typing.Any]]] = None,
+    experiments: typing.Optional[typing.Union[_cdktf_cdktf_provider_kubernetes_provider_b14d7399.KubernetesProviderExperiments, typing.Dict[builtins.str, typing.Any]]] = None,
+    host: typing.Optional[builtins.str] = None,
+    ignore_annotations: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ignore_labels: typing.Optional[typing.Sequence[builtins.str]] = None,
+    insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    password: typing.Optional[builtins.str] = None,
+    proxy_url: typing.Optional[builtins.str] = None,
+    token: typing.Optional[builtins.str] = None,
+    username: typing.Optional[builtins.str] = None,
+    cdk8s_app: _cdk8s_d3d9af27.App,
+) -> None:
+    """Type checking stubs"""
+    pass
